        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 33 <br>1,2,3,4,5,6,7,8,9,10,11,12,14,15,16,17,21,23,24,27,28,30,31,34,36,38,40,42,43,45,46,47,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 18 <strong>control</strong><br>0,13,18,19,20,22,25,26,29,32,33,35,37,39,41,44,48,49';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 33 <br>1,2,3,4,5,6,7,8,9,10,11,12,14,15,16,17,21,23,24,27,28,30,31,34,36,38,40,42,43,45,46,47,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 18 <strong>control</strong><br>0,13,18,19,20,22,25,26,29,32,33,35,37,39,41,44,48,49';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 33 <br>1,2,3,4,5,6,7,8,9,10,11,12,14,15,16,17,21,23,24,27,28,30,31,34,36,38,40,42,43,45,46,47,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 18 <strong>control</strong><br>0,13,18,19,20,22,25,26,29,32,33,35,37,39,41,44,48,49';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 33 <br>1,2,3,4,5,6,7,8,9,10,11,12,14,15,16,17,21,23,24,27,28,30,31,34,36,38,40,42,43,45,46,47,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 18 <strong>control</strong><br>0,13,18,19,20,22,25,26,29,32,33,35,37,39,41,44,48,49';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 33 <br>1,2,3,4,5,6,7,8,9,10,11,12,14,15,16,17,21,23,24,27,28,30,31,34,36,38,40,42,43,45,46,47,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 18 <strong>control</strong><br>0,13,18,19,20,22,25,26,29,32,33,35,37,39,41,44,48,49';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 33 <br>1,2,3,4,5,6,7,8,9,10,11,12,14,15,16,17,21,23,24,27,28,30,31,34,36,38,40,42,43,45,46,47,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260530 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 18 <strong>control</strong><br>0,13,18,19,20,22,25,26,29,32,33,35,37,39,41,44,48,49';}
}
